cocos.draw module — cocos v0.6.5 documentation

# cocos.draw module

class `Canvas`

  Bases: `cocos.cocosnode.CocosNode`

  `build_vbo`()
  `draw`()
  `endcap`(line, cap_type)
  `free`()
  `line_to`(end)
  `move_to`(position)
  `on_exit`()
  `pop`()
  `push`()
  `rotate`(radians)
  `set_color`(color)
  `set_endcap`(cap)
  `set_join`(join)
  `set_stroke_width`(stroke_width)
  `translate`(vect)

class `Context`

  Bases: `object`

  `copy`()
  `set_state`()
  `unset_state`()

class `Line`(start, end, color, stroke_width=1)

  Bases: `cocos.draw.Canvas`

  `render`()
  `color`
  `end`
  `start`
  `stroke_width`

class `Segment`(start, end, width)

  Bases: `object`

  `reversed`()
  `bl`
  `br`
  `direction`
  `left`
  `line_width`
  `points`
  `right`
  `tl`
  `tr`

`flatten`(*args)

`parameter`(default=None)